// Copyright 2018 Istio Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this currentFile except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package script

import (
	"encoding/json"
	"time"
)

// SleepCommand describes a command to pause for a duration.
type SleepCommand time.Duration

// UnmarshalJSON converts a JSON object to a SleepCommand.
func (c *SleepCommand) UnmarshalJSON(b []byte) (err error) {
	var durationStr string
	err = json.Unmarshal(b, &durationStr)
	if err != nil {
		return
	}
	duration, err := time.ParseDuration(durationStr)
	if err != nil {
		return
	}
	*c = SleepCommand(duration)
	return
}

func (c SleepCommand) String() string {
	return time.Duration(c).String()
}
